(function(/*! Brunch !*/) {
  'use strict';

  var globals = typeof window !== 'undefined' ? window : global;
  if (typeof globals.require === 'function') return;

  var modules = {};
  var cache = {};

  var has = function(object, name) {
    return ({}).hasOwnProperty.call(object, name);
  };

  var expand = function(root, name) {
    var results = [], parts, part;
    if (/^\.\.?(\/|$)/.test(name)) {
      parts = [root, name].join('/').split('/');
    } else {
      parts = name.split('/');
    }
    for (var i = 0, length = parts.length; i < length; i++) {
      part = parts[i];
      if (part === '..') {
        results.pop();
      } else if (part !== '.' && part !== '') {
        results.push(part);
      }
    }
    return results.join('/');
  };

  var dirname = function(path) {
    return path.split('/').slice(0, -1).join('/');
  };

  var localRequire = function(path) {
    return function(name) {
      var dir = dirname(path);
      var absolute = expand(dir, name);
      return globals.require(absolute);
    };
  };

  var initModule = function(name, definition) {
    var module = {id: name, exports: {}};
    definition(module.exports, localRequire(name), module);
    var exports = cache[name] = module.exports;
    return exports;
  };

  var require = function(name) {
    var path = expand(name, '.');

    if (has(cache, path)) return cache[path];
    if (has(modules, path)) return initModule(path, modules[path]);

    var dirIndex = expand(path, './index');
    if (has(cache, dirIndex)) return cache[dirIndex];
    if (has(modules, dirIndex)) return initModule(dirIndex, modules[dirIndex]);

    throw new Error('Cannot find module "' + name + '"');
  };

  var define = function(bundle, fn) {
    if (typeof bundle === 'object') {
      for (var key in bundle) {
        if (has(bundle, key)) {
          modules[key] = bundle[key];
        }
      }
    } else {
      modules[bundle] = fn;
    }
  };

  globals.require = require;
  globals.require.define = define;
  globals.require.register = define;
  globals.require.brunch = true;
})();

window.require.register("application", function(exports, require, module) {
  (function() {
    var Application;

    Application = {
      initialize: function() {
        var CalculatorModel, ConfigModel, HomeView, InfoView, ParametersView, PotentialView, ProfileView, Router;
        HomeView = require('views/home_view');
        ParametersView = require('views/parameters_view');
        ProfileView = require('views/profile_view');
        PotentialView = require('views/potential_view');
        InfoView = require('views/info_view');
        ConfigModel = require('models/config');
        CalculatorModel = require('models/calculator');
        Router = require('lib/router');
        this.views = {};
        this.views.home = new HomeView();
        this.views.parameters = new ParametersView();
        this.views.profile = new ProfileView();
        this.views.potential = new PotentialView();
        this.views.info = new InfoView();
        this.models = {};
        this.models.config = new ConfigModel();
        this.models.calculator = new CalculatorModel();
        this.models.config.setLang();
        this.router = new Router();
        return typeof Object.freeze === "function" ? Object.freeze(this) : void 0;
      }
    };

    module.exports = Application;

  }).call(this);
  
});
window.require.register("initialize", function(exports, require, module) {
  (function() {
    var application;

    application = require('application');

    $(function() {
      application.initialize();
      return Backbone.history.start();
    });

  }).call(this);
  
});
window.require.register("lib/router", function(exports, require, module) {
  (function() {
    var Router, application,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    application = require('application');

    module.exports = Router = (function(_super) {

      __extends(Router, _super);

      function Router() {
        Router.__super__.constructor.apply(this, arguments);
      }

      Router.prototype.latest = '';

      Router.prototype.routes = {
        '': 'startup',
        'home': 'home',
        'parameters': 'parameters',
        'profile': 'profile',
        'potential': 'potential',
        'info': 'info'
      };

      Router.prototype.initialize = function() {
        var _this = this;
        $(document).bind("pageinit", function(event, data) {
          return _this.currentPage.loaded();
        });
        $('body').append(application.views.info.render().startup().el);
        $('body').append(application.views.potential.render().startup().el);
        $('body').append(application.views.profile.render().startup().el);
        $('body').append(application.views.parameters.render().startup().el);
        $('body').append(application.views.home.render().startup().el);
        return $.mobile.initializePage();
      };

      Router.prototype.startup = function() {
        var page;
        this.latest = 'home';
        page = application.views.home;
        this.currentPage = page;
        return $.mobile.changePage($(page.el), {
          changeHash: false,
          transition: 'none'
        });
      };

      Router.prototype.home = function() {
        var page;
        this.latest = 'home';
        page = application.views.home;
        page.showContent();
        return this.changePage(page, true);
      };

      Router.prototype.info = function() {
        this.latest = 'info';
        return this.changePage(application.views.info);
      };

      Router.prototype.parameters = function() {
        var reverse;
        if (this.latest === 'profile') reverse = true;
        if (this.latest === 'potential') reverse = true;
        if (this.latest === 'info') reverse = true;
        this.latest = 'parameters';
        return this.changePage(application.views.parameters, reverse);
      };

      Router.prototype.profile = function() {
        var reverse;
        if (this.latest === 'potential') reverse = true;
        if (this.latest === 'info') reverse = true;
        this.latest = 'profile';
        return this.changePage(application.views.profile, reverse);
      };

      Router.prototype.potential = function() {
        var reverse;
        if (this.latest === 'info') reverse = true;
        this.latest = 'potential';
        return this.changePage(application.views.potential, reverse);
      };

      Router.prototype.changePage = function(page, reverse, changepage) {
        if (reverse == null) reverse = false;
        if (changepage == null) changepage = true;
        this.currentPage = page;
        page.refresh();
        if (changepage) {
          return $.mobile.changePage($(page.el), {
            changeHash: false,
            transition: 'slide',
            reverse: reverse
          });
        }
      };

      return Router;

    })(Backbone.Router);

  }).call(this);
  
});
window.require.register("lib/view_helper", function(exports, require, module) {
  (function() {



  }).call(this);
  
});
window.require.register("models/calculator", function(exports, require, module) {
  (function() {
    var CalculatorModel, EngineModel, Model, app,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    app = require('application');

    Model = require('./model');

    EngineModel = require('models/engine');

    module.exports = CalculatorModel = (function(_super) {

      __extends(CalculatorModel, _super);

      function CalculatorModel() {
        CalculatorModel.__super__.constructor.apply(this, arguments);
      }

      CalculatorModel.prototype.supreme = null;

      CalculatorModel.prototype.engine = null;

      CalculatorModel.prototype.initialize = function(attributes) {
        this.supreme = new EngineModel();
        this.supreme.setEngine('supreme');
        return this.engine = new EngineModel();
      };

      CalculatorModel.prototype.setProfile = function(profile) {
        this.supreme.setProfile(profile);
        return this.engine.setProfile(profile);
      };

      CalculatorModel.prototype.setCapacity = function(capacity) {
        this.supreme.setCapacity(capacity);
        return this.engine.setCapacity(capacity);
      };

      CalculatorModel.prototype.setRpm = function(rpm) {
        this.supreme.setRpm(rpm);
        return this.engine.setRpm(rpm);
      };

      CalculatorModel.prototype.setEngine = function(engine) {
        return this.engine.setEngine(engine);
      };

      CalculatorModel.prototype.calcCostbenefit = function() {
        var costbenefit, diff;
        diff = this.engine.calcEnergy() - this.supreme.calcEnergy();
        return costbenefit = Math.round(diff * app.models.config.get('cost')) / 100;
      };

      CalculatorModel.prototype.showCostbenefit = function() {
        var costbenefit;
        costbenefit = this.calcCostbenefit();
        switch (app.models.config.getLang()) {
          case 'en':
            return costbenefit = '€ ' + costbenefit;
          case 'de':
            return costbenefit = (String(costbenefit).split('.').join(',')) + ' €';
          case 'fr':
            return costbenefit = (String(costbenefit).split('.').join(',')) + ' €';
        }
      };

      return CalculatorModel;

    })(Model);

  }).call(this);
  
});
window.require.register("models/collection", function(exports, require, module) {
  (function() {
    var Collection,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    module.exports = Collection = (function(_super) {

      __extends(Collection, _super);

      function Collection() {
        Collection.__super__.constructor.apply(this, arguments);
      }

      return Collection;

    })(Backbone.Collection);

  }).call(this);
  
});
window.require.register("models/config", function(exports, require, module) {
  (function() {
    var ConfigModel, Model,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    Model = require('./model');

    module.exports = ConfigModel = (function(_super) {

      __extends(ConfigModel, _super);

      function ConfigModel() {
        ConfigModel.__super__.constructor.apply(this, arguments);
      }

      ConfigModel.prototype.defaults = {
        'aps': [1, .421875, .125, .015625],
        'cost': 15,
        'runtime': 6000,
        'platform': 'android',
        'language': 'en'
      };

      ConfigModel.prototype.isAndroid = function() {
        return this.get('platform' === 'android');
      };

      ConfigModel.prototype.setLang = function(lang) {
        if (window.navigator.language.indexOf('de') !== -1 && !lang) lang = 'de';
        if (window.navigator.language.indexOf('fr') !== -1 && !lang) lang = 'fr';
        if (!lang) lang = 'en';
        return this.set('language', lang);
      };

      ConfigModel.prototype.getLang = function() {
        return this.get('language');
      };

      return ConfigModel;

    })(Model);

  }).call(this);
  
});
window.require.register("models/engine", function(exports, require, module) {
  (function() {
    var EngineModel, Model, app,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    app = require('application');

    Model = require('./model');

    module.exports = EngineModel = (function(_super) {

      __extends(EngineModel, _super);

      function EngineModel() {
        EngineModel.__super__.constructor.apply(this, arguments);
      }

      EngineModel.prototype.profile = null;

      EngineModel.prototype.timeslices = null;

      EngineModel.prototype.engine = null;

      EngineModel.prototype.rpm = null;

      EngineModel.prototype.capacity = null;

      EngineModel.prototype.initialize = function(attributes) {
        this.setProfile();
        this.setEngine();
        this.setRpm();
        return this.setCapacity();
      };

      EngineModel.prototype.setProfile = function(profile) {
        if (profile == null) profile = 'blueangel';
        this.profile = profile;
        this.timeslices = engine_timeslices({
          name: this.profile
        });
        if (!this.timeslices.count()) return this.setProfile();
      };

      EngineModel.prototype.getProfile = function() {
        if (this.timeslices) return this.timeslices.select('slices')[0];
      };

      EngineModel.prototype.getProfileString = function() {
        var name;
        name = this.profile;
        if (name === 'blueangel') return 'Blauer Engel';
        if (name === 'partload') return 'Volllast';
        if (name === 'fullload') return 'Teillast';
      };

      EngineModel.prototype.setEngine = function(engine) {
        if (!engine) engine = this.engine;
        if (!engine) engine = 'ie2';
        this.engine = engine_data({
          name: engine
        });
        if (!this.engine.count()) {
          this.engine = null;
          return this.setEngine();
        }
      };

      EngineModel.prototype.getEngine = function() {
        return this.engine.select('name')[0];
      };

      EngineModel.prototype.getEngineString = function() {
        var name;
        name = this.engine.select('name')[0];
        if (name === 'ie2') return 'IE2';
        if (name === 'ie3') return 'IE3';
        if (name === 'supreme') return 'SuPremE';
      };

      EngineModel.prototype.setRpm = function(rpm) {
        if (!rpm) rpm = this.rpm;
        if (!rpm) rpm = '3000';
        return this.rpm = rpm;
      };

      EngineModel.prototype.getRpm = function() {
        return this.rpm;
      };

      EngineModel.prototype.setCapacity = function(capacity) {
        if (!capacity) capacity = this.capacity;
        if (!capacity) capacity = '0.75';
        return this.capacity = capacity;
      };

      EngineModel.prototype.getCapacity = function() {
        return this.capacity;
      };

      EngineModel.prototype.getEfficiencyfactors = function() {
        var capacities, details, efficiencyfactor;
        details = this.engine.select('details');
        if (!details[0][this.rpm]) {
          this.rpm = null;
          this.setEngine();
        }
        capacities = details[0][this.rpm];
        if (!details[0][this.rpm][this.capacity]) {
          this.capacity = null;
          this.setEngine();
          return;
        }
        return efficiencyfactor = details[0][this.rpm][this.capacity];
      };

      EngineModel.prototype.calcEnergy = function(log) {
        var efficiencyfactors, profile, total_energy;
        efficiencyfactors = this.getEfficiencyfactors();
        profile = this.getProfile();
        total_energy = 0;
        _.each(efficiencyfactors, function(efficiencyfactor, i) {
          var energy;
          energy = this.calcEnergyforefficiency(this.capacity, app.models.config.get('aps')[i], efficiencyfactor, profile[i]);
          return total_energy += energy;
        }, this);
        if (log) {
          console.log('Bemessungsleistung: ' + this.capacity);
          console.log('Bemessungsdrehzahl: ' + this.rpm);
          console.log('Betriebsstunden pro Jahr: ' + app.models.config.get('runtime'));
          console.log('Energiepreis: ' + app.models.config.get('cost'));
          console.log('Lastprofil: ' + this.profile);
          console.log('Motor: ' + this.engine.select('name'));
          console.log('-> Total: ' + Math.round(total_energy));
        }
        return total_energy;
      };

      EngineModel.prototype.calcCost = function(log) {
        var energy;
        energy = this.calcEnergy(log);
        return energy * app.models.config.get('cost');
      };

      EngineModel.prototype.calcEnergyforefficiency = function(capacity, ap_percent, efficiencyfactor, timeslice) {
        var energy;
        energy = 0;
        energy = (capacity * ap_percent) / (efficiencyfactor / 100) * timeslice / 100 * app.models.config.get('runtime');
        return energy;
      };

      return EngineModel;

    })(Model);

  }).call(this);
  
});
window.require.register("models/model", function(exports, require, module) {
  (function() {
    var Model,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    module.exports = Model = (function(_super) {

      __extends(Model, _super);

      function Model() {
        Model.__super__.constructor.apply(this, arguments);
      }

      Model.prototype.sync = function() {
        return true;
      };

      return Model;

    })(Backbone.Model);

  }).call(this);
  
});
window.require.register("views/home_view", function(exports, require, module) {
  (function() {
    var HomeView, View, app, templateDE, templateEN, templateFR,
      __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    View = require('./view');

    app = require('application');

    templateDE = require('./templates/de/home');

    templateEN = require('./templates/en/home');

    templateFR = require('./templates/fr/home');

    module.exports = HomeView = (function(_super) {

      __extends(HomeView, _super);

      function HomeView() {
        this.showContent = __bind(this.showContent, this);
        HomeView.__super__.constructor.apply(this, arguments);
      }

      HomeView.prototype.className = 'hide';

      HomeView.prototype.id = 'home-view';

      HomeView.prototype.template = {
        'de': templateDE,
        'en': templateEN,
        'fr': templateFR
      };

      HomeView.prototype.visible = false;

      HomeView.prototype.spState = 1;

      HomeView.prototype.events = {
        'tap button.next': 'nextPage'
      };

      HomeView.prototype.loaded = function() {
        var delay,
          _this = this;
        delay = 0;
        if (app.models.config.isAndroid()) delay = 3000;
        setTimeout(function() {
          return _this.startAnimation();
        }, delay);
        return this;
      };

      HomeView.prototype.startAnimation = function() {
        var height, no_of_frames, play_frames, width,
          _this = this;
        this.$('#intro-video').addClass('on');
        no_of_frames = 5;
        play_frames = 40;
        width = 300;
        height = 122;
        if (app.models.config.getLang() === 'de') no_of_frames = 6;
        if (app.models.config.getLang() === 'de') play_frames = 71;
        if (app.models.config.getLang() === 'de') height = 144;
        this.$('#intro-video').sprite({
          fps: 25,
          no_of_frames: no_of_frames,
          play_frames: play_frames,
          width: width,
          height: height,
          on_end_frame: function(obj) {
            obj.spToggle();
            return setTimeout(function() {
              return _this.showContent();
            }, 2000);
          },
          on_last_frame: function(obj) {
            _this.spState = _this.spState + 1;
            return obj.spState(_this.spState);
          }
        }).active();
        return this;
      };

      HomeView.prototype.showContent = function() {
        if (!this.visible) {
          this.$('.hide').fadeIn('slow');
          this.$('#intro-video').fadeOut('slow');
          return this.visible = true;
        }
      };

      HomeView.prototype.nextPage = function() {
        return app.router.navigate('parameters', {
          trigger: true
        });
      };

      return HomeView;

    })(View);

  }).call(this);
  
});
window.require.register("views/info_view", function(exports, require, module) {
  (function() {
    var InfoView, View, app, templateDE, templateEN, templateFR,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    View = require('./view');

    app = require('application');

    templateDE = require('./templates/de/info');

    templateEN = require('./templates/en/info');

    templateFR = require('./templates/fr/info');

    module.exports = InfoView = (function(_super) {

      __extends(InfoView, _super);

      function InfoView() {
        InfoView.__super__.constructor.apply(this, arguments);
      }

      InfoView.prototype.className = 'hide';

      InfoView.prototype.id = 'info-view';

      InfoView.prototype.template = {
        'de': templateDE,
        'en': templateEN,
        'fr': templateFR
      };

      InfoView.prototype.events = {
        'tap #home': 'homePage',
        'tap #number-1': 'gotoParameters',
        'tap #number-2': 'gotoProfile',
        'tap #number-3': 'gotoPotential'
      };

      InfoView.prototype.homePage = function() {
        return setTimeout(function() {
          return app.router.navigate('home', {
            trigger: true
          });
        }, 300);
      };

      InfoView.prototype.gotoParameters = function() {
        return setTimeout(function() {
          return app.router.navigate('parameters', {
            trigger: true
          });
        }, 300);
      };

      InfoView.prototype.gotoProfile = function() {
        return setTimeout(function() {
          return app.router.navigate('profile', {
            trigger: true
          });
        }, 300);
      };

      InfoView.prototype.gotoPotential = function() {
        return setTimeout(function() {
          return app.router.navigate('potential', {
            trigger: true
          });
        }, 300);
      };

      return InfoView;

    })(View);

  }).call(this);
  
});
window.require.register("views/parameters_view", function(exports, require, module) {
  (function() {
    var ParametersView, View, app, templateDE, templateEN, templateFR,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    View = require('./view');

    app = require('application');

    templateDE = require('./templates/de/parameters');

    templateEN = require('./templates/en/parameters');

    templateFR = require('./templates/fr/parameters');

    module.exports = ParametersView = (function(_super) {

      __extends(ParametersView, _super);

      function ParametersView() {
        ParametersView.__super__.constructor.apply(this, arguments);
      }

      ParametersView.prototype.className = 'hide';

      ParametersView.prototype.id = 'parameters-view';

      ParametersView.prototype.template = {
        'en': templateEN,
        'de': templateDE,
        'fr': templateFR
      };

      ParametersView.prototype.events = {
        'tap button.next': 'nextPage',
        'tap #home': 'homePage',
        'tap #info': 'infoPage',
        'tap #number-2': 'nextPage',
        'tap #number-3': 'gotoPotential',
        'change #capacity': 'setCapacity',
        'change #rpm-1': 'setRpm',
        'change #rpm-2': 'setRpm',
        'change #runtime': 'setRuntime',
        'change #cost': 'setCost'
      };

      ParametersView.prototype.getRenderData = function() {
        var data;
        return data = {
          runtime: app.models.config.get('runtime'),
          cost: app.models.config.get('cost')
        };
      };

      ParametersView.prototype.startup = function() {
        this.$('#capacity').val(app.models.calculator.engine.getCapacity());
        if (app.models.calculator.engine.getRpm() === '3000') {
          this.$('#rpm-1').attr('checked', true);
        } else {
          this.$('#rpm-2').attr('checked', true);
        }
        return this;
      };

      ParametersView.prototype.homePage = function() {
        return setTimeout(function() {
          return app.router.navigate('home', {
            trigger: true
          });
        }, 300);
      };

      ParametersView.prototype.infoPage = function() {
        return setTimeout(function() {
          return app.router.navigate('info', {
            trigger: true
          });
        }, 300);
      };

      ParametersView.prototype.nextPage = function() {
        return setTimeout(function() {
          return app.router.navigate('profile', {
            trigger: true
          });
        }, 300);
      };

      ParametersView.prototype.gotoPotential = function() {
        return setTimeout(function() {
          return app.router.navigate('potential', {
            trigger: true
          });
        }, 300);
      };

      ParametersView.prototype.setCapacity = function(e) {
        return app.models.calculator.setCapacity(e.currentTarget.value);
      };

      ParametersView.prototype.setRpm = function(e) {
        return app.models.calculator.setRpm(e.currentTarget.value);
      };

      ParametersView.prototype.setRuntime = function(e) {
        return app.models.config.set('runtime', e.currentTarget.value);
      };

      ParametersView.prototype.setCost = function(e) {
        return app.models.config.set('cost', e.currentTarget.value);
      };

      return ParametersView;

    })(View);

  }).call(this);
  
});
window.require.register("views/potential_view", function(exports, require, module) {
  (function() {
    var PotentialView, View, app, templateDE, templateEN, templateFR,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    View = require('./view');

    app = require('application');

    templateDE = require('./templates/de/potential');

    templateEN = require('./templates/en/potential');

    templateFR = require('./templates/fr/potential');

    module.exports = PotentialView = (function(_super) {

      __extends(PotentialView, _super);

      function PotentialView() {
        PotentialView.__super__.constructor.apply(this, arguments);
      }

      PotentialView.prototype.className = 'hide';

      PotentialView.prototype.id = 'potential-view';

      PotentialView.prototype.template = {
        'de': templateDE,
        'en': templateEN,
        'fr': templateFR
      };

      PotentialView.prototype.events = {
        'tap button.previous': 'previousPage',
        'tap #home': 'homePage',
        'tap #info': 'infoPage',
        'tap #number-1': 'gotoParameters',
        'tap #number-2': 'previousPage'
      };

      PotentialView.prototype.refresh = function() {
        this.$('.euro').html(app.models.calculator.showCostbenefit());
        this.$('#mailer').attr('href', 'mailto:?subject=' + this.getMailTitle(app.models.config.getLang()) + '&body=' + this.getMailText(app.models.config.getLang()));
        return null;
      };

      PotentialView.prototype.getMailTitle = function(lang) {
        switch (lang) {
          case 'en':
            return 'The energy diet that pays dividends';
          case 'fr':
            return 'Gagnez à vous mettre à la diète énergétique';
          case 'de':
            return 'Die Energiediät, die sich auszahlt';
        }
      };

      PotentialView.prototype.getMailText = function(lang) {
        switch (lang) {
          case 'en':
            return this.getMailTextEN();
          case 'fr':
            return this.getMailTextFR();
          case 'de':
            return this.getMailTextDE();
        }
      };

      PotentialView.prototype.getMailTextEN = function() {
        var mailtext;
        return mailtext = 'Here you will find potential savings offered by the new KSB SuPremE® motors for a system with the following operating parameters:%0D%0A%0D%0A\
\
Rated power: ' + app.models.calculator.engine.getCapacity() + ' kW%0D%0A\
Rated speed: ' + app.models.calculator.engine.getRpm() + ' rpm%0D%0A\
Annual operating hours: ' + app.models.config.get('runtime') + '%0D%0A\
Energy price: ' + app.models.config.get('cost') + ' ct./kWh%0D%0A%0D%0A\
\
Your potential savings: ' + app.models.calculator.showCostbenefit() + ' per year%0D%0A%0D%0A\
\
If this sounds interesting to you, find out more by visiting%0D%0A%0D%0A\
\
www.none-more-efficient.com%0D%0A%0D%0A\
\
Or contact us: www.ksb.com/contact';
      };

      PotentialView.prototype.getMailTextDE = function() {
        var mailtext;
        return mailtext = 'Hier finden Sie das Einsparpotenzial der neuen KSB SuPremE®-Motoren für eine Anlage mit den folgenden Betriebsparametern:%0D%0A%0D%0A\
\
Bemessungsleistung: ' + app.models.calculator.engine.getCapacity() + ' kW%0D%0A\
Bemessungsdrehzahl: ' + app.models.calculator.engine.getRpm() + ' U/min%0D%0A\
Betriebsstunden pro Jahr: ' + app.models.config.get('runtime') + '%0D%0A\
Energiepreis: ' + app.models.config.get('cost') + ' Cent/kWh%0D%0A%0D%0A\
\
Ihr Einsparpotenzial: ' + app.models.calculator.showCostbenefit() + '/Jahr%0D%0A%0D%0A\
\
Wenn das auch für Sie interessant klingt, erfahren Sie mehr unter www.keiner-ist-effizienter.de oder telefonisch unter%0D%0A%0D%0A\
\
+49 1805 5724-80*%0D%0A%0D%0A\
\
* Deutschlandweit zu Ihrem Vertriebshaus aus dem Festnetz 0,14 € /Minute (Mobilfunktarif kann höher ausfallen)';
      };

      PotentialView.prototype.getMailTextFR = function() {
        var mailtext;
        return mailtext = 'Le nouveau moteur SuPremE de KSB vous fait gagner en efficacité. Exemple d\'installation:%0D%0A%0D%0A\
\
Puissance nominale: ' + app.models.calculator.engine.getCapacity() + ' kW%0D%0A\
Vitesse de rotation nominale: ' + app.models.calculator.engine.getRpm() + ' U/min%0D%0A\
Heures de fonctionnement par an: ' + app.models.config.get('runtime') + '%0D%0A\
Coût kWh: ' + app.models.config.get('cost') + 'c/kWh%0D%0A%0D%0A\
\
Votre potentiel d\'économie est de ' + app.models.calculator.showCostbenefit() + '/ an%0D%0A%0D%0A\
\
Vous êtes intéressés ? Venez en apprendre plus sur le site internet http://fluidfuture.ksb.com/fr/';
      };

      PotentialView.prototype.getRenderData = function() {
        var data;
        return data = {
          potential_euro: app.models.calculator.calcCostbenefit()
        };
      };

      PotentialView.prototype.homePage = function() {
        return setTimeout(function() {
          return app.router.navigate('home', {
            trigger: true
          });
        }, 300);
      };

      PotentialView.prototype.infoPage = function() {
        return setTimeout(function() {
          return app.router.navigate('info', {
            trigger: true
          });
        }, 300);
      };

      PotentialView.prototype.previousPage = function() {
        return setTimeout(function() {
          return app.router.navigate('profile', {
            trigger: true
          });
        }, 300);
      };

      PotentialView.prototype.gotoParameters = function() {
        return setTimeout(function() {
          return app.router.navigate('parameters', {
            trigger: true
          });
        }, 300);
      };

      return PotentialView;

    })(View);

  }).call(this);
  
});
window.require.register("views/profile_view", function(exports, require, module) {
  (function() {
    var ProfileView, View, app, templateDE, templateEN, templateFR,
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    View = require('./view');

    app = require('application');

    templateDE = require('./templates/de/profile');

    templateEN = require('./templates/en/profile');

    templateFR = require('./templates/fr/profile');

    module.exports = ProfileView = (function(_super) {

      __extends(ProfileView, _super);

      function ProfileView() {
        ProfileView.__super__.constructor.apply(this, arguments);
      }

      ProfileView.prototype.className = 'hide';

      ProfileView.prototype.id = 'profile-view';

      ProfileView.prototype.template = {
        'de': templateDE,
        'en': templateEN,
        'fr': templateFR
      };

      ProfileView.prototype.events = {
        'tap button.next': 'nextPage',
        'tap button.previous': 'previousPage',
        'tap #home': 'homePage',
        'tap #info': 'infoPage',
        'tap #number-1': 'previousPage',
        'tap #number-3': 'nextPage',
        'change #blueangel': 'selectProfile',
        'change #partload': 'selectProfile',
        'change #fullload': 'selectProfile',
        'tap .button-modal': 'showModal',
        'change #ie2': 'selectEngine',
        'change #ie3': 'selectEngine'
      };

      ProfileView.prototype.startup = function() {
        var sel_profile;
        this.$el.find('.profile_detail').hide();
        sel_profile = app.models.calculator.engine.profile;
        this.$('#' + sel_profile).attr('checked', true);
        this.showProfileDetails(sel_profile);
        this.$('#' + app.models.calculator.engine.getEngine()).attr('checked', true);
        return this;
      };

      ProfileView.prototype.selectProfile = function(e) {
        app.models.calculator.setProfile(e.target.value);
        return this.showProfileDetails(e.target.value);
      };

      ProfileView.prototype.showProfileDetails = function(alias) {
        this.$el.find('.profile_detail').slideUp('fast');
        return this.$el.find('#detail-' + alias).slideDown('fast');
      };

      ProfileView.prototype.showModal = function(e) {
        e.preventDefault();
        return this.$el.find('#modal-' + e.currentTarget.name).simpledialog2();
      };

      ProfileView.prototype.selectEngine = function(e) {
        return app.models.calculator.setEngine(e.currentTarget.value);
      };

      ProfileView.prototype.nextPage = function() {
        return setTimeout(function() {
          return app.router.navigate('potential', {
            trigger: true
          });
        }, 300);
      };

      ProfileView.prototype.homePage = function() {
        return setTimeout(function() {
          return app.router.navigate('home', {
            trigger: true
          });
        }, 300);
      };

      ProfileView.prototype.infoPage = function() {
        return setTimeout(function() {
          return app.router.navigate('info', {
            trigger: true
          });
        }, 300);
      };

      ProfileView.prototype.previousPage = function() {
        return setTimeout(function() {
          return app.router.navigate('parameters', {
            trigger: true
          });
        }, 300);
      };

      return ProfileView;

    })(View);

  }).call(this);
  
});
window.require.register("views/templates/de/home", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header\">\n	<img src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h1 class=\"hide\">Der effizienteste magnetfreie Pumpenantrieb der Welt.</h1>\n	\n	<div class=\"de\" id=\"intro-video\"></div>\n\n	<div class=\"lower hide\">\n		<p>Die neue <strong>KSB SuPremE®-Motorengeneration</strong><br/>ist unschlagbar effizient.<br/>\n		Ermitteln Sie jetzt <strong>Ihr Einsparpotenzial</strong>.</p>\n		<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\" >Jetzt loslegen</button>\n	</div>\n</div>";});
});
window.require.register("views/templates/de/info", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Datenschutzhinweis</h2>\n\n	<p>KSB erfasst weder personen- oder endgerätbezogene Daten noch die individuell eingegebenen Daten und gibt keine Daten an Dritte weiter.</p>\n</div>";});
});
window.require.register("views/templates/de/parameters", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, self=this, functionType="function", helperMissing=helpers.helperMissing, undef=void 0, escapeExpression=this.escapeExpression;


    buffer += "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Betriebsparameter</h2>\n\n	<label for=\"capacity\" class=\"select\">Bemessungsleistung</label>\n	<select name=\"capacity\" id=\"capacity\" data-native-menu=\"true\" data-mini=\"true\">\n		<option value=\"0.55\">0,55 kW</option>\n		<option value=\"0.75\" selected>0,75 kW</option>\n		<option value=\"1.1\">1,1 kW</option>\n		<option value=\"1.5\">1,5 kW</option>\n		<option value=\"2.2\">2.2 kW</option>\n		<option value=\"3\">3 kW</option>\n		<option value=\"4\">4 kW</option>\n		<option value=\"5.5\">5,5 kW</option>\n		<option value=\"7.5\">7,5 kW</option>\n		<option value=\"11\">11 kW</option>\n		<option value=\"15\">15 kW</option>\n		<option value=\"18.5\">18,5 kW</option>\n		<option value=\"22\">22 kW</option>\n		<option value=\"30\">30 kW</option>\n		<option value=\"37\">37 kW</option>\n		<option value=\"45\">45 kW</option>\n	</select>\n\n	<label>Bemessungsdrehzahl</label>\n	<fieldset data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"rpm\" id=\"rpm-1\" value=\"3000\" />\n		<label for=\"rpm-1\">3.000 U/min</label>\n\n		<input type=\"radio\" name=\"rpm\" id=\"rpm-2\" value=\"1500\" />\n		<label for=\"rpm-2\">1.500 U/min</label>\n	</fieldset>\n\n	<label for=\"runtime\">Betriebsstunden pro Jahr</label>\n	<input type=\"range\" pattern=\"[0-9]*\" name=\"runtime\" id=\"runtime\" value=\"";
    foundHelper = helpers.runtime;
    stack1 = foundHelper || depth0.runtime;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "runtime", { hash: {} }); }
    buffer += escapeExpression(stack1) + "\" min=\"500\" max=\"8750\" step=\"250\" data-highlight=\"true\" />\n\n	<label for=\"cost\">Energiepreis (Cent/kWh)</label>\n	<input type=\"range\" pattern=\"[0-9]*\" name=\"cost\" id=\"cost\" value=\"";
    foundHelper = helpers.cost;
    stack1 = foundHelper || depth0.cost;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "cost", { hash: {} }); }
    buffer += escapeExpression(stack1) + "\" min=\"5\" max=\"25\" data-highlight=\"true\" />\n\n	<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\" data-theme=\"b\">Weiter zum Lastprofil</button>\n</div>";
    return buffer;});
});
window.require.register("views/templates/de/potential", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, self=this, functionType="function", helperMissing=helpers.helperMissing, undef=void 0, escapeExpression=this.escapeExpression;


    buffer += "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<div class=\"main\">\n		<h3>Ihr Einsparpotenzial:</h3>\n		<h2 class=\"euro\">";
    foundHelper = helpers.potential_euro;
    stack1 = foundHelper || depth0.potential_euro;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "potential_euro", { hash: {} }); }
    buffer += escapeExpression(stack1) + " €</h2>\n		<h3 class=\"light\">pro Jahr*</h3>\n	</div>\n\n	<a href=\"tel:+491805572480\" data-icon=\"ksb-phone\" data-iconpos=\"right\" data-role=\"button\">Telefonischer Kontakt</a>\n	<a href=\"http://www.keiner-ist-effizienter.de\" rel=\"external\" data-icon=\"ksb-web\" data-iconpos=\"right\" data-role=\"button\">KSB online besuchen</a>\n\n	<p class=\"light\">* Die berechneten Einsparwerte sind nicht verbindlich und können je nach exaktem Profil der Anlage abweichen.</p>\n\n	<a href=\"mailto:?subject=SuPremE%20Einsparpotenzial&body=...\" data-iconpos=\"right\" data-icon=\"ksb-email\" data-role=\"button\" data-theme=\"b\" id=\"mailer\">per E-Mail weiterleiten</a>\n\n	<button class=\"previous\" data-icon=\"arrow-l\" data-mini=\"true\" data-theme=\"a\">Angaben abändern</button>\n</div>";
    return buffer;});
});
window.require.register("views/templates/de/profile", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Lastprofil</h2>\n\n	<fieldset id=\"profile-group\" data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"profile\" id=\"blueangel\" value=\"blueangel\" />\n		<label for=\"blueangel\">\"Blauer Engel\"</label>\n		<div class=\"profile_detail\" id=\"detail-blueangel\">\n			<a href=\"#\" class=\"button-modal\" name=\"blueangel\">\n				<img src=\"images/profile-blueangel.png\">\n			</a>\n			<span>Lastprofil \"Blauer Engel\" ist typisch für Heizungs- und Kühlkreisläufe</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-blueangel\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Blauer Engel\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-blueangel-big.jpg\">\n		</div>\n\n		<input type=\"radio\" name=\"profile\" id=\"partload\" value=\"partload\"  />\n		<label for=\"partload\">Teillast-Betrieb</label>\n		<div class=\"profile_detail\" id=\"detail-partload\">\n			<a href=\"#\" class=\"button-modal\" name=\"partload\">\n				<img src=\"images/profile-partload.png\">\n			</a>\n			<span>Dauerhafter Betrieb bei Teillast-Betrieb (3/4 Last)</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-partload\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Teillast-Betrieb\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-partload-big.jpg\">\n		</div>\n		\n		<input type=\"radio\" name=\"profile\" id=\"fullload\" value=\"fullload\"  />\n		<label for=\"fullload\">Volllast-Betrieb</label>\n		<div class=\"profile_detail\" id=\"detail-fullload\">\n			<a href=\"#\" class=\"button-modal\" name=\"fullload\">\n				<img src=\"images/profile-fullload.png\">\n			</a>\n			<span>Dauerhafter Volllast-Betrieb</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-fullload\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Volllast-Betrieb\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-fullload-big.jpg\">\n		</div>\n		<div class=\"clearfix\"></div>\n	</fieldset>\n\n	<h2>Vergleichsbasis</h2>\n\n	<fieldset data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"engine\" id=\"ie2\" value=\"ie2\" checked=\"checked\" />\n		<label for=\"ie2\">IE2 (Stand der Technik)</label>\n\n		<input type=\"radio\" name=\"engine\" id=\"ie3\" value=\"ie3\"  />\n		<label for=\"ie3\">IE3 (Premium-Wirkungsgrad)</label>\n	</fieldset>\n\n	<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\" data-theme=\"b\">Einsparpotenzial berechnen</button>\n	<button class=\"previous\" data-icon=\"arrow-l\" data-mini=\"true\" data-theme=\"a\">Betriebsparameter abändern</button>\n</div>";});
});
window.require.register("views/templates/en/home", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header\">\n	<img src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h1 class=\"hide\">The world's most efficient magnet-less pump motor.</h1>\n	\n	<div class=\"en\" id=\"intro-video\"></div>\n\n	<div class=\"lower hide\">\n		<p>The new <strong>SuPremE® motor generation</strong> is unbeatably efficient.<br>Find out how much <strong>you can save</strong> with it.</p>\n		<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\" >Start now</button>\n	</div>\n</div>";});
});
window.require.register("views/templates/en/info", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Legal information</h2>\n\n	<p>KSB will record neither personal/end device data nor any data entered individually and will not disclose any data to third parties.</p>\n</div>";});
});
window.require.register("views/templates/en/parameters", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, self=this, functionType="function", helperMissing=helpers.helperMissing, undef=void 0, escapeExpression=this.escapeExpression;


    buffer += "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Operating parameters</h2>\n\n	<label for=\"capacity\" class=\"select\">Rated power</label>\n	<select name=\"capacity\" id=\"capacity\" data-native-menu=\"true\" data-mini=\"true\">\n		<option value=\"0.55\">0.55 kW</option>\n		<option value=\"0.75\" selected>0.75 kW</option>\n		<option value=\"1.1\">1.1 kW</option>\n		<option value=\"1.5\">1.5 kW</option>\n		<option value=\"2.2\">2.2 kW</option>\n		<option value=\"3\">3 kW</option>\n		<option value=\"4\">4 kW</option>\n		<option value=\"5.5\">5.5 kW</option>\n		<option value=\"7.5\">7.5 kW</option>\n		<option value=\"11\">11 kW</option>\n		<option value=\"15\">15 kW</option>\n		<option value=\"18.5\">18.5 kW</option>\n		<option value=\"22\">22 kW</option>\n		<option value=\"30\">30 kW</option>\n		<option value=\"37\">37 kW</option>\n		<option value=\"45\">45 kW</option>\n	</select>\n\n	<label>Rated speed</label>\n	<fieldset data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"rpm\" id=\"rpm-1\" value=\"3000\" />\n		<label for=\"rpm-1\">3,000 rpm</label>\n\n		<input type=\"radio\" name=\"rpm\" id=\"rpm-2\" value=\"1500\" />\n		<label for=\"rpm-2\">1,500 rpm</label>\n	</fieldset>\n\n	<label for=\"runtime\">Operating hours per year</label>\n	<input type=\"range\" pattern=\"[0-9]*\" name=\"runtime\" id=\"runtime\" value=\"";
    foundHelper = helpers.runtime;
    stack1 = foundHelper || depth0.runtime;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "runtime", { hash: {} }); }
    buffer += escapeExpression(stack1) + "\" min=\"500\" max=\"8750\" step=\"250\" data-highlight=\"true\" />\n\n	<label for=\"cost\">Energy price (ct./kWh)</label>\n	<input type=\"range\" pattern=\"[0-9]*\" name=\"cost\" id=\"cost\" value=\"";
    foundHelper = helpers.cost;
    stack1 = foundHelper || depth0.cost;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "cost", { hash: {} }); }
    buffer += escapeExpression(stack1) + "\" min=\"5\" max=\"25\" data-highlight=\"true\" />\n\n	<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\" data-theme=\"b\">Proceed to load profile</button>\n</div>";
    return buffer;});
});
window.require.register("views/templates/en/potential", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, self=this, functionType="function", helperMissing=helpers.helperMissing, undef=void 0, escapeExpression=this.escapeExpression;


    buffer += "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<div class=\"main\">\n		<h3>Your potential savings:</h3>\n		<h2 class=\"euro\">€ ";
    foundHelper = helpers.potential_euro;
    stack1 = foundHelper || depth0.potential_euro;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "potential_euro", { hash: {} }); }
    buffer += escapeExpression(stack1) + "</h2>\n		<h3 class=\"light\">per year*</h3>\n	</div>\n\n	<a href=\"http://www.ksb.com/ksb-en/contactfinder/\" data-icon=\"ksb-web\" data-iconpos=\"right\" data-role=\"button\">Email Contact</a>\n	<a href=\"http://www.none-more-efficient.com\" rel=\"external\" data-icon=\"ksb-web\" data-iconpos=\"right\" data-role=\"button\">Visit KSB online</a>\n\n	<p class=\"light\">* The calculated potential savings are non-binding, i.e., they depend on the exact system profile and may deviate accordingly.</p>\n\n	<a href=\"mailto:?subject=The%20energy%20diet%20that%20pays%20dividends&body=\" data-iconpos=\"right\" data-icon=\"ksb-email\" data-role=\"button\" data-theme=\"b\" id=\"mailer\">Forward by e-mail</a>\n\n	<button class=\"previous\" data-icon=\"arrow-l\" data-mini=\"true\" data-theme=\"a\">Alter entries</button>\n</div>";
    return buffer;});
});
window.require.register("views/templates/en/profile", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Load profile</h2>\n\n	<fieldset id=\"profile-group\" data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"profile\" id=\"blueangel\" value=\"blueangel\" />\n		<label for=\"blueangel\">\"Blue Angel\"</label>\n		<div class=\"profile_detail\" id=\"detail-blueangel\">\n			<a href=\"#\" class=\"button-modal\" name=\"blueangel\">\n				<img src=\"images/profile-blueangel-en.png\">\n			</a>\n			<span>The load profile to \"Blue Angel\" requirements is typical for heating and cooling circuits.</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-blueangel\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Blue Angel\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-blueangel-big-en.jpg\">\n		</div>\n\n		<input type=\"radio\" name=\"profile\" id=\"partload\" value=\"partload\"  />\n		<label for=\"partload\">Part load</label>\n		<div class=\"profile_detail\" id=\"detail-partload\">\n			<a href=\"#\" class=\"button-modal\" name=\"partload\">\n				<img src=\"images/profile-partload-en.png\">\n			</a>\n			<span>Continuous operation at part load (3/4 load)</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-partload\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Part load\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-partload-big-en.jpg\">\n		</div>\n		\n		<input type=\"radio\" name=\"profile\" id=\"fullload\" value=\"fullload\"  />\n		<label for=\"fullload\">Full load</label>\n		<div class=\"profile_detail\" id=\"detail-fullload\">\n			<a href=\"#\" class=\"button-modal\" name=\"fullload\">\n				<img src=\"images/profile-fullload-en.png\">\n			</a>\n			<span>Continuous operation at full load</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-fullload\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Full load\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-fullload-big-en.jpg\">\n		</div>\n		<div class=\"clearfix\"></div>\n	</fieldset>\n\n	<h2>Basis of comparison</h2>\n\n	<fieldset data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"engine\" id=\"ie2\" value=\"ie2\" checked=\"checked\" />\n		<label for=\"ie2\">IE2 (state of the art)</label>\n\n		<input type=\"radio\" name=\"engine\" id=\"ie3\" value=\"ie3\"  />\n		<label for=\"ie3\">IE3 (premium efficiency)</label>\n	</fieldset>\n\n	<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\" data-theme=\"b\">Calculate potential savings</button>\n	<button class=\"previous\" data-icon=\"arrow-l\" data-mini=\"true\" data-theme=\"a\">Alter entries</button>\n</div>";});
});
window.require.register("views/templates/fr/home", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header\">\n	<img src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h1 class=\"hide\">Le moteur sans aimants le plus efficace du monde.</h1>\n	\n	<div class=\"en\" id=\"intro-video\"></div>\n\n	<div class=\"lower hide\">\n		<p>Gagnez en efficacité avec la nouvelle génération de moteur SuPremE® de KSB. <strong>Déterminez votre potentiel</strong> d'économies</p>\n		<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\">Calculez</button>\n	</div>\n</div>";});
});
window.require.register("views/templates/fr/info", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Mention légale</h2>\n\n	<p>KSB ne saisit ni données personnelles ou relatives aux terminaux, ni données saisies individuellement et ne les transmet à aucun tiers.</p>\n</div>";});
});
window.require.register("views/templates/fr/parameters", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, self=this, functionType="function", helperMissing=helpers.helperMissing, undef=void 0, escapeExpression=this.escapeExpression;


    buffer += "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Vos données</h2>\n\n	<label for=\"capacity\" class=\"select\">Puissance nominale</label>\n	<select name=\"capacity\" id=\"capacity\" data-native-menu=\"true\" data-mini=\"true\">\n		<option value=\"0.55\">0.55 kW</option>\n		<option value=\"0.75\" selected>0.75 kW</option>\n		<option value=\"1.1\">1.1 kW</option>\n		<option value=\"1.5\">1.5 kW</option>\n		<option value=\"2.2\">2.2 kW</option>\n		<option value=\"3\">3 kW</option>\n		<option value=\"4\">4 kW</option>\n		<option value=\"5.5\">5.5 kW</option>\n		<option value=\"7.5\">7.5 kW</option>\n		<option value=\"11\">11 kW</option>\n		<option value=\"15\">15 kW</option>\n		<option value=\"18.5\">18.5 kW</option>\n		<option value=\"22\">22 kW</option>\n		<option value=\"30\">30 kW</option>\n		<option value=\"37\">37 kW</option>\n		<option value=\"45\">45 kW</option>\n	</select>\n\n	<label>Vitesse de rotation nominale</label>\n	<fieldset data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"rpm\" id=\"rpm-1\" value=\"3000\" />\n		<label for=\"rpm-1\">3,000 t/min (tours)</label>\n\n		<input type=\"radio\" name=\"rpm\" id=\"rpm-2\" value=\"1500\" />\n		<label for=\"rpm-2\">1,500 t/min (tours)</label>\n	</fieldset>\n\n	<label for=\"runtime\">Heures de fonctionnement par an</label>\n	<input type=\"range\" pattern=\"[0-9]*\" name=\"runtime\" id=\"runtime\" value=\"";
    foundHelper = helpers.runtime;
    stack1 = foundHelper || depth0.runtime;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "runtime", { hash: {} }); }
    buffer += escapeExpression(stack1) + "\" min=\"500\" max=\"8750\" step=\"250\" data-highlight=\"true\" />\n\n	<label for=\"cost\">Prix du kWh</label>\n	<input type=\"range\" pattern=\"[0-9]*\" name=\"cost\" id=\"cost\" value=\"";
    foundHelper = helpers.cost;
    stack1 = foundHelper || depth0.cost;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "cost", { hash: {} }); }
    buffer += escapeExpression(stack1) + "\" min=\"5\" max=\"25\" data-highlight=\"true\" />\n\n	<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\" data-theme=\"b\">Vos profils de charge</button>\n</div>";
    return buffer;});
});
window.require.register("views/templates/fr/potential", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var buffer = "", stack1, foundHelper, self=this, functionType="function", helperMissing=helpers.helperMissing, undef=void 0, escapeExpression=this.escapeExpression;


    buffer += "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number light\">2</span>\n	<span id=\"number-3\" class=\"number\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<div class=\"main\">\n		<h3>Votre potentiel d'économies:</h3>\n		<h2 class=\"euro\">€ ";
    foundHelper = helpers.potential_euro;
    stack1 = foundHelper || depth0.potential_euro;
    if(typeof stack1 === functionType) { stack1 = stack1.call(depth0, { hash: {} }); }
    else if(stack1=== undef) { stack1 = helperMissing.call(depth0, "potential_euro", { hash: {} }); }
    buffer += escapeExpression(stack1) + "</h2>\n		<h3 class=\"light\">Par année*</h3>\n	</div>\n\n	<a href=\"http://www.ksb.com/ksb-en/contactfinder/\" data-icon=\"ksb-web\" data-iconpos=\"right\" data-role=\"button\">Contact mail</a>\n	<a href=\"http://www.ksb.fr\" rel=\"external\" data-icon=\"ksb-web\" data-iconpos=\"right\" data-role=\"button\">Aller sur www.ksb.fr</a>\n\n	<p class=\"light\">* Les valeurs du potentiel d'économies  sont indicatives et peuvent différer selon le profil de charge exact</p>\n\n	<a href=\"mailto:?subject=The%20energy%20diet%20that%20pays%20dividends&body=\" data-iconpos=\"right\" data-icon=\"ksb-email\" data-role=\"button\" data-theme=\"b\" id=\"mailer\">Transférer par mail</a>\n\n	<button class=\"previous\" data-icon=\"arrow-l\" data-mini=\"true\" data-theme=\"a\">Modifier les paramètres</button>\n</div>";
    return buffer;});
});
window.require.register("views/templates/fr/profile", function(exports, require, module) {
  module.exports = Handlebars.template(function (Handlebars,depth0,helpers,partials,data) {
    helpers = helpers || Handlebars.helpers;
    var foundHelper, self=this;


    return "<div class=\"header-small\">\n	<span id=\"home\" class=\"number home light\">&nbsp;</span>\n	<span id=\"number-1\" class=\"number light\">1</span>\n	<span id=\"number-2\" class=\"number\">2</span>\n	<span id=\"number-3\" class=\"number light\">3</span>\n	<span id=\"info\" class=\"number light grey\">&nbsp;</span>\n\n	<img class=\"logo\" height=\"30\" src=\"images/ksb_logo.png\">\n</div>\n\n<div data-role=\"content\">\n	<h2>Profil de charge</h2>\n\n	<fieldset id=\"profile-group\" data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"profile\" id=\"blueangel\" value=\"blueangel\" />\n		<label for=\"blueangel\">\"Blue Angel\"</label>\n		<div class=\"profile_detail\" id=\"detail-blueangel\">\n			<a href=\"#\" class=\"button-modal\" name=\"blueangel\">\n				<img src=\"images/profile-blueangel-en.png\">\n			</a>\n			<span>Profil de charge type d'une application pompe.</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-blueangel\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Blue Angel\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-blueangel-big-en.jpg\">\n		</div>\n\n		<input type=\"radio\" name=\"profile\" id=\"partload\" value=\"partload\"  />\n		<label for=\"partload\">Chargement partiel</label>\n		<div class=\"profile_detail\" id=\"detail-partload\">\n			<a href=\"#\" class=\"button-modal\" name=\"partload\">\n				<img src=\"images/profile-partload-en.png\">\n			</a>\n			<span>Fonctionnement continu à charge partielle (3/4 de charge)</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-partload\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Chargement partiel\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-partload-big-en.jpg\">\n		</div>\n		\n		<input type=\"radio\" name=\"profile\" id=\"fullload\" value=\"fullload\"  />\n		<label for=\"fullload\">Chargement complet</label>\n		<div class=\"profile_detail\" id=\"detail-fullload\">\n			<a href=\"#\" class=\"button-modal\" name=\"fullload\">\n				<img src=\"images/profile-fullload-en.png\">\n			</a>\n			<span>Fonctionnement continu à pleine charge (4/4 de charge)</span>\n			<div class=\"clearfix\"></div>\n		</div>\n		<div\n			class=\"modal\"\n			id=\"modal-fullload\"\n			data-options='{\"mode\":\"blank\",\"animate\":\"fade\",\"headerText\":\"Chargement complet\",\"headerClose\":true,\"blankContent\":true}'\n		>\n			<img class=\"big\" src=\"images/profile-fullload-big-en.jpg\">\n		</div>\n		<div class=\"clearfix\"></div>\n	</fieldset>\n\n	<h2>Bases comparatives</h2>\n\n	<fieldset data-role=\"controlgroup\" data-mini=\"true\">\n		<input type=\"radio\" name=\"engine\" id=\"ie2\" value=\"ie2\" checked=\"checked\" />\n		<label for=\"ie2\">IE2</label>\n\n		<input type=\"radio\" name=\"engine\" id=\"ie3\" value=\"ie3\"  />\n		<label for=\"ie3\">IE3</label>\n	</fieldset>\n\n	<button class=\"next\" data-icon=\"arrow-r\" data-iconpos=\"right\" data-theme=\"b\">Calcul du potentiel d'économies</button>\n	<button class=\"previous\" data-icon=\"arrow-l\" data-mini=\"true\" data-theme=\"a\">Modification des paramètres</button>\n</div>";});
});
window.require.register("views/view", function(exports, require, module) {
  (function() {
    var View, app,
      __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
      __hasProp = Object.prototype.hasOwnProperty,
      __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

    app = require('application');

    require('lib/view_helper');

    module.exports = View = (function(_super) {

      __extends(View, _super);

      function View() {
        this.render = __bind(this.render, this);
        View.__super__.constructor.apply(this, arguments);
      }

      View.prototype.template = function() {};

      View.prototype.getRenderData = function() {};

      View.prototype.refresh = function() {
        return this;
      };

      View.prototype.loaded = function() {
        return this;
      };

      View.prototype.startup = function() {
        return this;
      };

      View.prototype.render = function() {
        this.$el.html(this.template[app.models.config.getLang()](this.getRenderData()));
        this.$el.attr('data-role', 'page');
        this.afterRender();
        return this;
      };

      View.prototype.afterRender = function() {};

      return View;

    })(Backbone.View);

  }).call(this);
  
});
